import React, { useEffect, useState } from "react";
import {Spin} from "antd";
import { ToastContainer } from "react-toastify";
import PageRoutes from "../../routes";
import Sidebar from "../Sidebar";
import s from "./styles.module.scss";
import api, {setConfig} from "../../api";

// @ts-ignore
window.api = api;

const host =
  window.location.hostname === "localhost"
    ? `new.didgram.pro:8091`
    : window.location.host;

const websocketUrl = `ws://${host}`;
const gatewayUrl = `http://${host}`;

const App = () => {
  const [isAppLoading, setIsAppLoading] = useState(true);

  useEffect(() => {
    (async () => {
      setConfig({
        websocketUrl,
        gatewayUrl,
        getToken: async () => '',
      });
      await api.initialize()
      await api.openConnection();
      setIsAppLoading(false);
    })();
  }, []);

  let content;
  if (isAppLoading) {
    content = (
      <div className={s.loader}>
        <Spin size="large" tip="Loading..." />
      </div>
    );
  } else {
    content = (
      <div className={s.body}>
        <Sidebar />
        <div className={s.workspaceArea}>
          <div className={s.content}>
            <PageRoutes />
          </div>
        </div>
      </div>
    );
  }
  return (
    <div className={s.root}>
      {content}
      <ToastContainer />
    </div>
  );
};

export default App;
