import React, { useEffect, useState } from "react";
import { observer } from "mobx-react";
import { Form, Input, Button, Modal } from 'antd';
import api from "../../../../api";
import {toast} from "react-toastify";
import s from "./styles.module.scss";

export interface ReceiveInvitationDialogProps {
  onInvitationReceived: (connection: any) => void;
  onClose: () => void;
}

const ReceiveInvitationDialog = observer(
  ({ onClose, onInvitationReceived }: ReceiveInvitationDialogProps) => {
    const [open, setOpen] = useState(false);
    useEffect(() => {
      setOpen(true);
    }, []);
    const [loading, setLoading] = useState(false);

    const onFinish = async ({ invitation }: any) => {
      try {
        setLoading(true);
        const connRecord = await api.connections.connectionControllerAcceptInvitation({ invitationUrl: invitation });
        toast(`Invitation received`);
        if (connRecord) {
          onInvitationReceived(connRecord);
        }
      } catch (e: any) {
        console.error(e);
        toast(e.message);
      }
      setLoading(false);
    };

    return (
      <Modal
        style={{ top: 60 }}
        open={open}
        title="Add new agent"
        onCancel={onClose}
        footer={[]}
      >
        <div className={s.body}>
          <Form
            layout="vertical"
            initialValues={{
              invitation: ''
            }}
            onFinish={onFinish}
            autoComplete="off"
          >
            <Form.Item
              label="outOfBandInvitationUrl"
              name="invitation"
              rules={[{ required: true, message: 'Please enter invitation!' }]}
            >
              <Input.TextArea rows={12} />
            </Form.Item>

            <div className={s.footerActions}>
              <Button type="primary" htmlType="submit" disabled={loading}>
                Create
              </Button>
              <Button
                className={s.cancelButton}
                onClick={onClose}
                disabled={loading}
              >
                Close
              </Button>
            </div>
          </Form>
        </div>
      </Modal>
    );
  }
);

export default ReceiveInvitationDialog;
