import React, {useEffect, useState} from "react";
import { observer } from "mobx-react";
import {Button, Spin} from 'antd';
import {Link, useNavigate} from "react-router-dom";
import ConnectionListStore from './ConnectionListStore';
import config from "../../../routes/config";
import ConnectionItem from "../../../components/ConnectionItem";
import ReceiveInvitationDialog from "./ReceiveInvitationDialog";

const ConnectionListPage = observer(() => {
  const [store] = useState(() => new ConnectionListStore());
  const [receiveInvDialogOpened, setReceiveInvDialogOpened] = useState(false);

  const navigate = useNavigate();


  useEffect(() => {
    store.getAll()
  }, [])
  return (
    <div>
      <h2>
        Actions
      </h2>
      <div>
        <Link to={config.connection_create.getLink()}>
          <Button>
            Create new invitation
          </Button>
        </Link>
        <Button onClick={() => setReceiveInvDialogOpened(true)}>
          Receive invitation
        </Button>
      </div>
      <h2>Connection List</h2>
      <div>
        {store.list.map(p => (
          <ConnectionItem
            key={p.id}
            item={p}
            onOpen={() => navigate(config.connection_view.getLink(p.id))}
          />
        ))}
        {store.loading && (
          <Spin />
        )}
      </div>

      {receiveInvDialogOpened && (
        <ReceiveInvitationDialog
          onInvitationReceived={(connRecord) => {
            navigate(config.connection_view.getLink(connRecord.connectionId));
            setReceiveInvDialogOpened(false);
          }}
          onClose={() => { setReceiveInvDialogOpened(false) }}
        />
      )}
    </div>
  );
});

export default ConnectionListPage;
