import React, { useEffect, useState } from "react";
import { observer } from "mobx-react";
import {Form, Input, Button, Modal} from 'antd';
import api from "../../../../api";
import {toast} from "react-toastify";
import s from "./styles.module.scss";


export interface NewCredentialDefDialogProps {
  onCredDefCreated: (credDef: any) => void;
  onClose: () => void;
}

const NewCredentialDefDialog = observer(
  ({ onClose, onCredDefCreated }: NewCredentialDefDialogProps) => {
    const [open, setOpen] = useState(false);
    useEffect(() => {
      setOpen(true);
    }, []);
    const [loading, setLoading] = useState(false);

    const onFinish = async ({ schemaId, tag }: any) => {
      try {
        setLoading(true);

        const schema = await api.schema.attestationControllerGetSchemaById({ schemaId });
        if (!schema) {
          throw new Error('Schema with specified id not found');
        }

        const credDef = await api.credentials.attestationControllerCreateCredentialDefinition({
          schemaId,
          tag,
        });
        console.log(credDef);
        toast(`New credential definition created`);
        onCredDefCreated(credDef);
      } catch (e: any) {
        console.error(e);
        toast(e.message);
      }
      setLoading(false);
    };

    return (
      <Modal
        style={{ top: 60 }}
        open={open}
        title="Add new credetial definition"
        onCancel={onClose}
        footer={[]}
      >
        <div className={s.body}>
          <Form
            layout="vertical"
            labelCol={{ span: 8 }}
            wrapperCol={{ span: 16 }}
            style={{ maxWidth: 600 }}
            initialValues={{
              schemaId: '',
              tag: ''
            }}
            onFinish={onFinish}
            autoComplete="off"
          >
            <Form.Item
              label="Schema Id"
              name="schemaId"
              rules={[{ required: true, message: 'Please enter schemaId!' }]}
            >
              <Input />
            </Form.Item>
            <Form.Item
              label="Tag"
              name="tag"
              rules={[{ required: true, message: 'Please enter tag!' }]}
            >
              <Input />
            </Form.Item>

            <div className={s.footerActions}>
              <Button type="primary" htmlType="submit" disabled={loading}>
                Create
              </Button>
              <Button
                className={s.cancelButton}
                onClick={onClose}
                disabled={loading}
              >
                Close
              </Button>
            </div>
          </Form>

        </div>
      </Modal>
    );
  }
);

export default NewCredentialDefDialog;

