import React, { useEffect, useState } from "react";
import { observer } from "mobx-react";
import {Form, Input, Button, Modal, Select} from 'antd';
import api from "../../../../api";
import {toast} from "react-toastify";
import s from "./styles.module.scss";


export interface NewSchemaDialogProps {
  onSchemaCreated: (schema: any) => void;
  onClose: () => void;
}

const NewSchemaDialog = observer(
  ({ onClose, onSchemaCreated }: NewSchemaDialogProps) => {
    const [open, setOpen] = useState(false);
    useEffect(() => {
      setOpen(true);
    }, []);
    const [loading, setLoading] = useState(false);

    const onFinish = async (values: any) => {
      try {
        setLoading(true);
        const schema = await api.schema.attestationControllerCreateSchema(values);
        toast(`New schema ${schema.id} created`);
        onSchemaCreated(schema);
      } catch (e: any) {
        console.error(e);
        toast(e.message);
      }
      setLoading(false);
    };

    return (
      <Modal
        style={{ top: 60 }}
        open={open}
        title="Add new schema"
        onCancel={onClose}
        footer={[]}
      >
        <div>
          Creating schema not supported at the moment
        </div>
        <div className={s.body}>
          <Form
            layout="vertical"
            labelCol={{ span: 8 }}
            wrapperCol={{ span: 16 }}
            style={{ maxWidth: 600 }}
            initialValues={{
              name: '',
              version: '',
              attributes: []
            }}
            onFinish={onFinish}
            autoComplete="off"
          >
            <Form.Item
              label="Name"
              name="name"
              rules={[{ required: true, message: 'Please enter name!' }]}
            >
              <Input />
            </Form.Item>
            <Form.Item
              label="Version"
              name="version"
              rules={[{ required: true, message: 'Please enter version!' }]}
            >
              <Input />
            </Form.Item>
            <Form.Item
              label="Attributes"
              name="attributes"
              rules={[{ required: true, message: 'Please enter attributes!' }]}
            >
              <Select
                mode="tags"
                style={{ width: '100%' }}
              />
            </Form.Item>

            <div className={s.footerActions}>
              <Button type="primary" htmlType="submit" disabled={loading}>
                Create
              </Button>
              <Button
                className={s.cancelButton}
                onClick={onClose}
                disabled={loading}
              >
                Close
              </Button>
            </div>
          </Form>

        </div>
      </Modal>
    );
  }
);

export default NewSchemaDialog;
