import { registerAs } from "@nestjs/config";
import * as process from "process";
import { IConfAgent } from "../interfaces/agent.config.interface";

const endpoints = process.env["AGENT_PEER_URL"]!.split(",");
let agentWsPeerPort: number | null = null;
let agentWsPeerAddress: string | null = null;
let agentHttpPeerPort: number | null = null;
let agentHttpPeerAddress: string | null = null;

const wsEndpoint = endpoints.find(
  (p) => p.startsWith("ws") || p.startsWith("wss"),
);
if (wsEndpoint) {
  agentWsPeerPort = parseInt(wsEndpoint.split(":")[2]);
  agentWsPeerAddress = wsEndpoint;
}
const httpEndpoint = endpoints.find(
  (p) => p.startsWith("http") || p.startsWith("https"),
);
if (httpEndpoint) {
  agentHttpPeerPort = parseInt(httpEndpoint.split(":")[2]);
  agentHttpPeerAddress = httpEndpoint;
}

export const agentConfig = registerAs(
  "agent",
  (): IConfAgent => ({
    agentWsPeerPort,
    agentWsPeerAddress,
    agentHttpPeerPort,
    agentHttpPeerAddress,
    agentName: process.env["AGENT_NAME"]!,
    agentKey: process.env["AGENT_KEY"]!,
    agentDidSeed: process.env["AGENT_DID_SEED"]!,
    agentDbHost: process.env["AGENT_DB_HOST"]!,
    agentDbUser: process.env["AGENT_DB_USER"]!,
    agentDbPass: process.env["AGENT_DB_PASS"]!,
    agentIsRest: process.env["AGENT_IS_REST"] === "true",
    agentConsumerName: process.env["AGENT_CONSUMER_NAME"]!,
    agentConsumerMaxMessagess: parseInt(process.env["AGENT_MAX_MESSAGES"]!),
    agentConsumerRateLimit: parseInt(process.env["AGENT_RETE_LIMIT"]!),
    agentPort: parseInt(process.env["AGENT_PORT"]!),
  }),
);
